
*********************************************************
*  The double burden of being a woman and obese: evidence from the Chilean Labor Market 
*          By: Mauricio Sarrias and Victor Iturra
*          This do file create the main tables and figures for the article
*********************************************************


set more off, perm
global raw "/Users/mauriciosarrias/Dropbox/Work/Health/Obesity&Wage/Published-versions/Replicate"
use "$raw/panel_obesity_jfe", replace


			   *===========================*
			   *  Set FLAG for estimation  *
			   *===========================*

	   
*** Global mincer  
global mincer_nhour "schooling exp c.exp#c.exp age c.age#c.age married i.race i.ms i.fs i.year i.sector i.region"

** Generate flag 1
quie reg lhwage bmi $mincer_nhour  i.female    i.female#c.bmi if dependency != 2
gen flag = 1 if e(sample)


			   *=============================*
			   * Table 1: Summary Statistics *  
			   *=============================*
			   
* Generate dummy variables
tabulate sector , nofreq gen(sec)
tabulate year   , nofreq gen(y)
tabulate region , nofreq gen(reg)
tabulate bmi_cat, nofreq gen(obc)
tabulate ms, nofreq generate(dms)
tabulate fs, nofreq generate(dfs)

* Globals
global var1 "bmi weight height obc1 obc2 obc3 obc4 lhwage schooling exp age"
global var2 "married race y1-y4 dms* dfs*"

* Generate table
eststo clear
sort female
by female: eststo: quietly estpost summarize $var1 $var2 if flag == 1
esttab, cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2)) count(fmt(0))") ///
        collabels("\multicolumn{1}{c}{Mean}" "\multicolumn{1}{c}{SD}" "\multicolumn{1}{c}{Min}" "\multicolumn{1}{c}{Max}" "\multicolumn{1}{c}{N}" ///
		"\multicolumn{1}{c}{Mean}" "\multicolumn{1}{c}{SD}" "\multicolumn{1}{c}{Min}" "\multicolumn{1}{c}{Max}" "\multicolumn{1}{c}{N}", span ) ///
		title("Summary Statistics\label{tab:summary}") ///
		mtitle("Men" "Women") ///
		coeflabels(bmi  " \emph{-BMI (k/m$^2$)}" ///
		           weight  " \emph{-Weight (in kilograms)}" ///
				   height  "\emph{-Height (in centimeters)}" ///
		           obc1 " \emph{-Underweight (BMI $<$ 18.5)}" ///
				   obc2 " \emph{-Normal/healthy weight ($18.5 \leq \text{BMI}  \leq 24.9$)}" ///
				   obc3 " \emph{-Overweight ($25 \leq \text{BMI}  \leq 29.9$)}" ///
				   obc4 " \emph{-Obese ($\text{BMI} > 30$)}" ///
				   lhwage " \emph{- ln hourly wage}" ///
				   schooling " \emph{-Schooling (in years)}" ///
				   exp " \emph{-Experience (in years)}" ///
				   age " \emph{-Age (in years)}" ///
				   married " \emph{-Married ( = 1)}" ///
				   race " \emph{-Indigenous (= 1)}" ///
				   dms1 " \emph{-No education}" ///
				   dms2 " \emph{-Primary education}" ///
				   dms3 " \emph{-Secondary education}" ///
				   dms4 " \emph{-High education}" ///
				   dms5 " \emph{-Missing}" ///
				   dfs1 " \emph{-No education}" ///
				   dfs2 " \emph{-Primary education}" ///
				   dfs3 " \emph{-Secondary education}" ///
				   dfs4 " \emph{-High education}" ///
				   dfs5 " \emph{-Missing}" ///
				   y1 " \emph{-2004}" /// 
				   y2 " \emph{-2006}" ///
				   y3 " \emph{-2009}" ///
				   y4 " \emph{-2015}") ///
		refcat(bmi "\textbf{Weight Measures:}" lhwage "\textbf{Mincer's Variables:}" dms1 "\textbf{Mother's education}" dfs1 "\textbf{Father's education}" y1 "\textbf{Years dummy}", nolabel) ///
		longtable nonumber noobs nogaps compress replace
		

			   *==========*
			   * Figure 1 *  
			   *==========*
			   
** Nutritional Status Women by Year
tab bmi_cat, gen(nut)
graph bar (mean) nut1 (mean) nut2 (mean) nut3 (mean) nut4 if flag == 1, ///
             over(year) over(female, relabel(1 "Men" 2 "Women")) ///
			 legend(order(1 "Underweight" 2 "Normal weight" 3 "Overweight" 4 "Obese")) scheme(sj) 



			   *=========*
			   * Table 2 *  
			   *=========*
			   
set more off, perm
eststo m1: reg lhwage bmi                                           if flag == 1, vce(cluster folio_n)		
nlcom (exp(_b[bmi] * 1) - 1) * 100
eststo m2: reg lhwage bmi $mincer_nhour  i.female                   if flag == 1, vce(cluster folio_n)
nlcom (exp(_b[bmi] * 1) - 1) * 100
 
eststo m3: reg lhwage bmi $mincer_nhour  i.female i.female#c.bmi	if flag == 1, vce(cluster folio_n)
margins female,  vce(unconditional) expression(exp(predict(xb))) post

eststo m4: reg lhwage bmi $mincer_nhour                           	if flag == 1 & female == 0, vce(cluster folio_n)
eststo m5: reg lhwage bmi $mincer_nhour                             if flag == 1 & female == 1, vce(cluster folio_n)	
esttab m1 m2 m3 m4 m5, ///
b(4) se(4) ///
star(* 0.1 ** 0.05 *** 0.01) ///
title("Unconditional and conditional correlations between log of hourly wage \& BMI\label{tab:pool}") ///
drop(0.* 1.fs 1.ms) ///
order(bmi 1.female 1.female#c.bmi) ///
coeflabels(bmi    "\emph{BMI (weight / height$^2$)}" ///
           schooling "\emph{Schooling (years of completed education)}" ///
		   married "\emph{Married ( = 1 if married)}" ///
		   exp "\emph{Experience (years of actual experience)}" ///
		   c.exp#c.exp "\emph{Experience$^2$}" ///
		   age "\emph{Age (in years)}" ///
		   c.age#c.age "\emph{Age$^2$}" ///
		   1.race "\emph{Indigenous ( = 1 if belongs to an indigenous group)}" ///
		   1.female "\emph{Female}" ///
		   1.female#c.bmi "\emph{Female\$\times\$BMI}" ///
		   2.ms "\emph{Primary}" ///
		   3.ms "\emph{Secondary}" ///
		   4.ms "\emph{High}" ///
		   5.ms "\emph{Missing}" ///
		   2.fs "\emph{Primary}" ///
		   3.fs "\emph{Secondary}" ///
		   4.fs "\emph{High}" ///
		   5.fs "\emph{Missing}" ///
		   _cons "\emph{Constant}") ///
indicate("Year Dummies = *.year" ///
		 "Sector Dummies = *.sector" ///
		 "Regional Dummies = *.region", label(\checkmark)) ///
stats(N r2_a, fmt(0 3) labels("N" "R2 adj")) ///
refcat(schooling "\textbf{\emph{Productivity variables}}" married "\textbf{\emph{Demographic variables}}" 2.ms "\textbf{\emph{Mother's Education: No education as reference}}" 2.fs "\textbf{\emph{Father's Education: No education as reference}}", nolabel) ///
mgroups("Men and Women" "Men" "Women", pattern(1 0 0 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
compress nogaps nodepvar longtable replace nomtitle nonotes



			   *=========*
			   * Table 3 *  
			   *=========*
			   
gen lnbmi = ln(bmi)

eststo m1:  xi: reg lhwage bmi                  $mincer_nhour if flag == 1 & female == 1, vce(cluster folio_n)
eststo m2:  xi: reg lhwage weight height 		$mincer_nhour if flag == 1 & female == 1, vce(cluster folio_n) 
eststo m3:  xi: reg lhwage lnbmi 		        $mincer_nhour if flag == 1 & female == 1, vce(cluster folio_n)
eststo m4:  xi: reg lhwage ib(2).bmi_cat 		$mincer_nhour if flag == 1 & female == 1, vce(cluster folio_n)
eststo m5:  xi: reg lhwage bmi                  $mincer_nhour if flag == 1 & female == 0, vce(cluster folio_n)
eststo m6:  xi: reg lhwage weight height 		$mincer_nhour if flag == 1 & female == 0, vce(cluster folio_n) 
eststo m7:  xi: reg lhwage lnbmi 		        $mincer_nhour if flag == 1 & female == 0, vce(cluster folio_n)
eststo m8:  xi: reg lhwage ib(2).bmi_cat 		$mincer_nhour if flag == 1 & female == 0, vce(cluster folio_n)
esttab m1 m2 m3 m4 m5 m6 m7 m8, ///
b(4) se(4) ///
star(* 0.1 ** 0.05 *** 0.01) ///
title("Sensitivity of weight-penalty to different specifications of body size \label{tab:sensitivity}") ///
order(bmi weight height lnbmi 1.bmi_cat 3.bmi_cat 4.bmi_cat) ///
coeflabels(bmi    "\emph{BMI (weight / height$^2$)}" ///
           weight "\emph{Weight in kilogram}" ///
		   height "\emph{Height in centimeters}" ///
		   lnbmi "\emph{ln(BMI)}" ///
		   1.bmi_cat "\emph{Underweight (BMI $<$ 19)}" ///
		   3.bmi_cat "\emph{Overweight (25 $<$ BMI $<$ 30)}" ///
		   4.bmi_cat "\emph{Obese (BMI $>$ 30)}") ///
drop(_cons 2.bmi_cat) ///
indicate("Year Dummies = _Iyear*" ///
			"Sector Dummies = _Isect*" "Regional Dummies = _Ireg*" ///
			"Mincer Controls = schooling married exp c.exp#c.exp _Irace_1 age c.age#c.age" ///
			"Family Background = _Ims_* _Ifs_*",  label(\checkmark)) ///
stats(N r2_a, fmt(0 3) labels("N" "R2 adj")) ///
refcat(1.bmi_cat "\textbf{\emph{Normal weight as reference}}", nolabel) ///
mgroups("\emph{Women}" "\emph{Men}", pattern(1 0 0 0 1 0 0 0) ///
      prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
compress nogaps nodepvar nomtitle longtable replace nonotes

			   *==========*
			   * Figure 2 *  
			   *==========*
			   
* standardized values
egen fzbmi = std(bmi) if female == 1
egen mzbmi = std(bmi) if female == 0


*** Generate treatment variables
_pctile fzbmi if female == 1, percentiles(50 55 60 65 70 75 80 85 90 95)
return list
local i = 1
foreach n of numlist 50 55 60 65 70 75 80 85 90 95 {
	gen byte TF_`n' = fzbmi >= `r(r`i')' if fzbmi ! = . & female == 1
	local ++i
}
*** Generate male
_pctile mzbmi if female == 0, percentiles(50 55 60 65 70 75 80 85 90 95)
return list
local i = 1
foreach n of numlist 50 55 60 65 70 75 80 85 90 95 {
	gen byte TM_`n' = mzbmi >= `r(r`i')' if mzbmi ! = . & female == 0
	local ++i
}

* Regressions for women
quietly eststo m_50:reg lhwage TF_50 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_55:reg lhwage TF_55 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_60:reg lhwage TF_60 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_65:reg lhwage TF_65 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_70:reg lhwage TF_70 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_75:reg lhwage TF_75 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_80:reg lhwage TF_80 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_85:reg lhwage TF_85 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_90:reg lhwage TF_90 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  
quietly eststo m_95:reg lhwage TF_95 $mincer_nhour    if flag == 1 & female == 1, vce(cluster folio_n)  

* Plot for women
coefplot (m_50, rename(TF_50 = ">50th")) ///
		 (m_55, rename(TF_55 = ">55th")) ///
		 (m_60, rename(TF_60 = ">60th")) ///
		 (m_65, rename(TF_65 = ">65th")) ///
		 (m_70, rename(TF_70 = ">70th")) ///
		 (m_75, rename(TF_75 = ">75th")) ///
		 (m_80, rename(TF_80 = ">80th")) ///
		 (m_85, rename(TF_85 = ">85th")) ///
		 (m_90, rename(TF_90 = ">90th")) ///
		 (m_95, rename(TF_95 = ">95th")),  keep(TF_*) xline(0) ///
		scheme(sj) norecycle byopts(legend(off)) legend(off) ///
		mlabel format(%9.3f) mlabposition(12) mlabgap(*1.21) ///
		title("A: Women") saving("$res/women_z", replace)

* Regressions for men
quietly eststo m_50:reg lhwage TM_50 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_55:reg lhwage TM_55 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_60:reg lhwage TM_60 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_65:reg lhwage TM_65 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_70:reg lhwage TM_70 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_75:reg lhwage TM_75 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_80:reg lhwage TM_80 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_85:reg lhwage TM_85 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_90:reg lhwage TM_90 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  
quietly eststo m_95:reg lhwage TM_95 $mincer_nhour    if flag == 1 & female == 0, vce(cluster folio_n)  

* Plot for men
coefplot (m_50, rename(TM_50 = ">50th")) ///
		 (m_55, rename(TM_55 = ">55th")) ///
		 (m_60, rename(TM_60 = ">60th")) ///
		 (m_65, rename(TM_65 = ">65th")) ///
		 (m_70, rename(TM_70 = ">70th")) ///
		 (m_75, rename(TM_75 = ">75th")) ///
		 (m_80, rename(TM_80 = ">80th")) ///
		 (m_85, rename(TM_85 = ">85th")) ///
		 (m_90, rename(TM_90 = ">90th")) ///
		 (m_95, rename(TM_95 = ">95th")),  keep(TM_*) xline(0) ///
		scheme(sj) norecycle byopts(legend(off)) legend(off) ///
		mlabel format(%9.3f) mlabposition(12) mlabgap(*1.21) ///
		title("B: Men") saving("$res/men_z", replace)

gr combine "$res/women_z" "$res/men_z", col(1)

			   *==========*
			   * Figure 3 *  
			   *==========*

*** Quadratic term for men
reg lhwage bmi c.bmi#c.bmi $mincer_nhour if flag == 1 & female == 0, vce(cluster folio_n)
display - _b[bmi] / (2 * _b[c.bmi#c.bmi])
margins, dydx(bmi) at(bmi = (15(1)40)) vce(unconditional)
marginsplot, xline(30) yline(0) scheme(sj) ytitle("Marginal effect on log of hourly wage") xtitle("Body mass index") title("B: Men") saving("$res/me_men", replace)

*** Quadratic term for women
reg lhwage bmi c.bmi#c.bmi $mincer_nhour if flag == 1 & female == 1, vce(cluster folio_n)
display - _b[bmi] / (2 * _b[c.bmi#c.bmi])
margins, dydx(bmi) at(bmi = (15(1)40)) vce(unconditional)
marginsplot, xline(19) yline(0) scheme(sj) ytitle("Marginal effect on log of hourly wage") xtitle("Body mass index") title("A: Women") saving("$res/me_women", replace)

gr combine "$res/me_women" "$res/me_men", row(1)



			   *==========*
			   * Table 4 *  
			   *==========*

* set xset
egen t = group(year)
xtset folio_n t
global panelvar "schooling exp age married i.year"


**** BMI****
eststo m1: xi: xtreg    lhwage           bmi $panelvar                 if dependency != 2 & female == 1, fe 
eststo m2: xi: xtreg    lhwage           bmi $panelvar                 if dependency != 2 & female == 1, re
hausman m1 ., sigmamore
 
eststo m3: xi: xtivreg2 lhwage               $panelvar  (bmi = bmi_iv) if dependency != 2 & female == 1, fe small first
estadd scalar F_ff = e(widstat)
estadd scalar F_p = e(idp)

eststo m4: xi: xtivreg lhwage                $panelvar  (bmi = bmi_iv) if dependency != 2 & female == 1, re small first
xtoverid, noi
estadd scalar F_ff = 170.63
estadd scalar F_p = 0.0000

ivregress 2sls lhwage                        $panelvar  (bmi = orw)    if dependency != 2 & female == 1,  small first


eststo m5: xi: xtreg lhwage             bmi  $panelvar                 if dependency != 2 & female == 0, fe  
eststo m6: xi: xtreg lhwage             bmi  $panelvar                 if dependency != 2 & female == 0, re  
eststo m7: xi: xtivreg2 lhwage               $panelvar  (bmi = bmi_iv) if dependency != 2 & female == 0, fe  small first
estadd scalar F_ff = e(widstat)
estadd scalar F_p = e(idp)

eststo m8: xi: xtivreg lhwage               $panelvar  (bmi = bmi_iv)   if dependency != 2 & female == 0, re small first
xtoverid, noi
estadd scalar F_ff = 121.88
estadd scalar F_p = 0.0000

esttab m1 m2 m3 m4 m5 m6 m7 m8, ///
b(4) se(4) ///
star(* 0.1 ** 0.05 *** 0.01) ///
mgroups("Women" "Men", pattern(1 0 0 0 1 0 0 0)) ///
mtitle("FE" "RE" "IV-FE" "IV-RE" "FE" "RE" "IV-FE" "IV-RE") ///
stats(F_ff F_p N, fmt(4 4 0 ) labels("F first stage" "Prob > F" "Observations")) ///
compress nogap


**** Obese ****
eststo m1: xi: xtreg    lhwage           obese $panelvar                if dependency != 2 & female == 1, fe 
eststo m2: xi: xtreg    lhwage           obese $panelvar                if dependency != 2 & female == 1, re 
hausman m1 ., sigmamore
eststo m3: xi: xtivreg2 lhwage                 $panelvar  (obese = orw) if dependency != 2 & female == 1, fe small first
estadd scalar F_ff = e(widstat)
estadd scalar F_p = e(idp)

eststo m4: xi: xtivreg lhwage                  $panelvar  (obese = orw) if dependency != 2 & female == 1, re small first
xtoverid, noi
estadd scalar F_ff = 170.63
estadd scalar F_p = 0.0000

ivregress 2sls lhwage                          $panelvar  (obese = orw) if dependency != 2 & female == 1,  small first


eststo m5: xi: xtreg lhwage             obese  $panelvar                if dependency != 2 & female == 0, fe  
eststo m6: xi: xtreg lhwage             obese  $panelvar                if dependency != 2 & female == 0, re  
eststo m7: xi: xtivreg2 lhwage                 $panelvar  (obese = orm) if dependency != 2 & female == 0, fe  small first
estadd scalar F_ff = e(widstat)
estadd scalar F_p = e(idp)

eststo m8: xi: xtivreg lhwage                  $panelvar  (obese  = orm) if dependency != 2 & female == 0, re small first
xtoverid, noi
estadd scalar F_ff = 27.280
estadd scalar F_p = 0.0000


esttab m1 m2 m3 m4 m5 m6 m7 m8, ///
b(4) se(4) ///
star(* 0.1 ** 0.05 *** 0.01) ///
mgroups("Women" "Men", pattern(1 0 0 0 1 0 0 0)) ///
mtitle("FE" "RE" "IV-FE" "IV-RE" "FE" "RE" "IV-FE" "IV-RE") ///
stats(F_ff F_p N, fmt(4 4 0 ) labels("F first stage" "Prob > F" "Observations")) ///
compress nogap


  
			   
			   *==========*
			   * Table 5 *  
			   *==========*

*** Flag 1
reg lhwage raver ///
    $mincer_nhour 
gen fob_2 = 1 if e(sample)

*** Flag2
reg lhwage sick_leave p_exer p_stairs p_walk smoker ///
    $mincer_nhour 
gen fob_1 = 1 if e(sample)

	   
**** Decomposing obese-nonobese difference in wage
eststo m1: oaxaca lhwage  ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m2: oaxaca lhwage  ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m3: oaxaca lhwage  ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & fob_1 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m4: oaxaca lhwage  sick_leave p_exer	 p_stairs    p_walk ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & fob_1 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m5: oaxaca lhwage ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & fob_1 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m6: oaxaca lhwage sick_leave p_exer	 p_stairs    p_walk ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & fob_1 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m7: oaxaca lhwage ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & fob_2 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m8: oaxaca lhwage  raver ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & fob_2 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m9: oaxaca lhwage smoker ///
          (productivity: schooling exp age training) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & fob_2 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m10: oaxaca lhwage raver  ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & fob_2 == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m11: oaxaca lhwage ocw ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m12: oaxaca lhwage ocw ///
          (productivity: schooling exp age) ///
		  (socioeconomic: married race) ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
esttab m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12,  b(3) se(3) ///
star(* 0.1 ** 0.05 *** 0.01) ///
substitute(\_ _) ///
title("OB decomposition of log of hourly wage: Obese vs non obese\label{tab:oxaca-full}") ///
keep(overall:group_1 overall:group_2 overall:difference overall:explained overall:unexplained) ///
coeflabel(overall:group_1 "$\ln(w_{mean}^{NO})$" ///
          overall:group_2 "$\ln(w_{mean}^{O})$" ///
		  overall:difference "$\ln(w_{mean}^{NO})-\ln(w_{mean}^{O}$)" ///
		  overall:explained "Explained part" ///
		  overall:unexplained "Unexplained part") ///
mtitle("Women" "Men" ///
      "\shortstack{Women \\ Without P\&S}" "\shortstack{Women \\ With P\&S}" "\shortstack{Men \\ Without P\&S}" "\shortstack{Men\\ With P\&S}" ///
	  "\shortstack{Women \\ Without RA}" "\shortstack{Women \\ With RA}" "\shortstack{Men \\ Without RA}" "\shortstack{Men\\ With RA}" ///
	  "Women" "Men" ) ///
mgroups("Same controls" "Controlling for presenteeism/absenteeism" "Controlling for risk aversion" "Controlling for crowding", pattern(1 0 1 0 0 0 1 0 0 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  ///
compress nogaps nodepvar longtable replace nonotes eqlabels(none)
		  

			   *==========*
			   * Table 7  *  
			   *==========*
			   
		   
eststo m1: oaxaca lhwage schooling married exp race age ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1 & collar == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m2: oaxaca lhwage schooling married exp race age  ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1 & collar == 2, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m3: oaxaca lhwage schooling married exp  race age  ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1 & collar == 3, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m4: oaxaca lhwage schooling married exp  race age ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 1 & flag == 1 & collar == 4, by(obese)  pooled noisily vce(cluster folio_n) relax
esttab m1 m2 m3 m4,   b(3) se(3) ///
star(* 0.1 ** 0.05 *** 0.01) ///
keep(overall:group_1 overall:group_2 overall:difference overall:explained overall:unexplained) ///
substitute(\_ _) ///
title("OB decomposition of log of hourly wage: Obese vs non obese women by occupational categories \label{tab:oxaca-women}") ///
coeflabel(overall:group_1 "$\ln(w_{mean}^{NO})$" ///
          overall:group_2 "$\ln(w_{mean}^{O})$" ///
		  overall:difference "$\ln(w_{mean}^{NO})-\ln(w_{mean}^{O}$)" ///
		  overall:explained "Explained part" ///
		  overall:unexplained "Unexplained part") ///
mtitle("White collar (HS)" "White collar (LS)" "Blue collar (HS)" "Blue collar (HS)") ///
compress nogaps nodepvar longtable replace nonotes eqlabels(none)
	
			   *==========*
			   * Table 8  *  
			   *==========*

		  
eststo m1: oaxaca lhwage schooling married exp race age  ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1 & collar == 1, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m2: oaxaca lhwage schooling married exp race age ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1 & collar == 2, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m3: oaxaca lhwage schooling married exp race age  ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1 & collar == 3, by(obese)  pooled noisily vce(cluster folio_n) relax
eststo m4: oaxaca lhwage schooling married exp race age ///
          (regions: normalize(reg1-reg13)) ///
	      (sector : normalize(sec1-sec9)) ///
	      (year   : normalize(y1-y4)) ///
	      (father : normalize(dfs1-dfs5)) ///
	      (mother : normalize(dms1-dms5)) if female == 0 & flag == 1 & collar == 4, by(obese)  pooled noisily vce(cluster folio_n) relax
esttab m1 m2 m3 m4,   b(3) se(3) ///
star(* 0.1 ** 0.05 *** 0.01) ///
keep(overall:group_1 overall:group_2 overall:difference overall:explained overall:unexplained) ///
substitute(\_ _) ///
title("OB decomposition of log of hourly wage: Obese vs non obese men by occupational categories \label{tab:oxaca-men}") ///
coeflabel(overall:group_1 "$\ln(w_{mean}^{NO})$" ///
          overall:group_2 "$\ln(w_{mean}^{O})$" ///
		  overall:difference "$\ln(w_{mean}^{NO})-\ln(w_{mean}^{O}$)" ///
		  overall:explained "Explained part" ///
		  overall:unexplained "Unexplained part") ///
mtitle("White collar (HS)" "White collar (LS)" "Blue collar (HS)" "Blue collar (HS)") ///
compress nogaps nodepvar longtable replace nonotes eqlabels(none)
	
	
			   *==========*
			   * Table 6  *  
			   *==========*

eststo m1: reg lhwage i.obese              $mincer_nhour   if flag == 1 & female == 1, vce(cluster folio_n) 
eststo m2: reg lhwage i.obese  c.ocw       $mincer_nhour   if flag == 1 & female == 1, vce(cluster folio_n) 
eststo m3: reg lhwage i.obese##c.ocw       $mincer_nhour   if flag == 1 & female == 1, vce(cluster folio_n) 
eststo m4: reg lhwage i.obese              $mincer_nhour   if flag == 1 & female == 0, vce(cluster folio_n) 
eststo m5: reg lhwage i.obese  c.ocw       $mincer_nhour   if flag == 1 & female == 0, vce(cluster folio_n) 
eststo m6: reg lhwage i.obese##c.ocw       $mincer_nhour   if flag == 1 & female == 0, vce(cluster folio_n) 
esttab m1 m2 m3 m4 m5 m6, ///
title("Crowding and wage-gap : Obese vs non obese\label{tab:crowding}") ///
b(3) se(3) ///
star(* 0.1 ** 0.05 *** 0.01) ///
drop(0* _cons) ///
coeflabel(1.obese "\emph{Obese}" ///
          ocw    "\emph{Crowding}" ///
		  1.obese#c.ocw "\emph{Obese $\times$ Crowding}") ///
indicate("Year Dummies = *.year" ///
			"Sector Dummies = *.sector*" "Regional Dummies = *.region*" ///
			"Mincer Controls = schooling married exp c.exp#c.exp 1.race age c.age#c.age" ///
			"Family Background = *.ms *.fs",  label(\checkmark)) ///
mtitle("Women" "Women" "Women" "Men" "Men" "Men") ///
stats(N r2_a, fmt(0 3) labels("N" "R2 adj")) ///
compress nogaps nodepvar longtable replace nonotes

			   *======================================*
			   * Generate sample for Figures 5 and 6  *  
			   *======================================*
* Panel setup
xtset folio_n year

* Reshaping
keep  sector  height weight female age married exp schooling region bmi lnbmi ///
         hwage lhwage collar ms fs  bmi_cat year race folio_n
		 
reshape wide  sector height weight female age married exp schooling region bmi lnbmi ///
         hwage lhwage collar ms fs  bmi_cat  race, i(folio_n) j(year)
		 
*  Generate control and treatment by sex:
recode ms2004 (4 = 1) (nonmissing = 0), gen(HM2004)
recode fs2004 (4 = 1) (nonmissing = 0), gen(HF2004)

foreach n of numlist 2004 2006 2009 2015 {
	egen zFbmi`n' = std(bmi`n') if female`n' == 1
	egen zMbmi`n' = std(bmi`n') if female`n' == 0
}

_pctile zFbmi2004, percentiles(5 10 15 85 90 95)
_pctile zMbmi2004, percentiles(5 10 15 85 90 95)

foreach x of numlist 2004 2006 2009 2015 {
	_pctile zFbmi`x', percentiles(85 90 95)
	return list
	local i = 1
	foreach n of numlist 85 90 95 {
		gen byte TF`x'_`n' = zFbmi`x' >= `r(r`i')' if zFbmi`x' ! = .
		local ++i
		}
}

foreach x of numlist 2004 2006 2009 2015 {
	_pctile zFbmi`x', percentiles(5 10 15)
	return list
	local i = 1
	foreach n of numlist 5 10 15 {
		gen byte TF`x'_`n' = zFbmi`x' <= `r(r`i')' if zFbmi`x' ! = .
		local ++i
	}
}

foreach x of numlist 2004 2006 2009 2015 {
	_pctile zMbmi`x', percentiles(85 90 95)
	return list
	local i = 1
	foreach n of numlist 85 90 95 {
		gen byte TM`x'_`n' = zMbmi`x' >= `r(r`i')' if zMbmi`x' ! = .
		local ++i
		}
}

foreach x of numlist 2004 2006 2009 2015 {
	_pctile zMbmi`x', percentiles(5 10 15)
	return list
	local i = 1
	foreach n of numlist 5 10 15 {
		gen byte TM`x'_`n' = zMbmi`x' <= `r(r`i')' if zMbmi`x' ! = .
		local ++i
	}
}

label define plab 0 " < 5" ///
                  1 "5-10" ///
                  2 "15-5" ///
                  3 "20-15" ///
                  4 "25-20" ///				  
                  5 "20-25" ///
                  6 "35-30" ///				  
                  7 "40-35" ///				  
                  8 "45-40" ///				  
                  9 "50-45" ///
                  10 "55-50" ///				  
                  11 "60-55" ///				  
                  12 "65-60" ///				  
                  13 "70-65" ///
                  14 "75-70" ///				  
                  15 "80-75" ///				  
                  16 "85-80" ///				  
                  17 "90-85" ///
                  18 "95-90" ///	
				  19 "> 95" 
				  
foreach x of numlist 2004 2006 2009 2015 {
    gen TF`x'_All = .
	_pctile zFbmi`x', percentiles(5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95)
	return list
	forvalues i = 1/18 {
		local j = `i' + 1 
		replace TF`x'_All = `i' if (zFbmi`x' < `r(r`j')' & zFbmi`x' >= `r(r`i')') & zFbmi`x' ! = .
	}
	replace TF`x'_All = 0  if zFbmi`x' < r(r1)  & zFbmi`x' ! = .
    replace TF`x'_All = 19 if zFbmi`x' > r(r19) & zFbmi`x' ! = .
	label values TF`x'_All plab
}

				  
foreach x of numlist 2004 2006 2009 2015 {
    gen TM`x'_All = .
	_pctile zMbmi`x', percentiles(5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95)
	return list
	forvalues i = 1/18 {
		local j = `i' + 1 
		replace TM`x'_All = `i' if (zMbmi`x' < `r(r`j')' & zMbmi`x' >= `r(r`i')') & zMbmi`x' ! = .
	}
	replace TM`x'_All = 0  if zMbmi`x' < r(r1)  & zMbmi`x' ! = .
    replace TM`x'_All = 19 if zMbmi`x' > r(r19) & zMbmi`x' ! = .
	label values TM`x'_All plab
}

				  
			   *==========*
			   * Figure 5 *  
			   *==========*
reg married2004 exp2004 schooling2004 race2004 HM2004 HF2004
gen flag = 1 if e(sample)

foreach x of numlist  2006 2009 2015{
	gen BchF`x' = .
	replace BchF`x' = 1 if TF2004_All > 14   & TF`x'_All  > 14  &  TF`x'_All ! = . & TF2004_All! = .
	replace BchF`x' = 2 if TF2004_All > 14   & TF`x'_All  <= 14  &  TF`x'_All ! = . & TF2004_All! = .
	replace BchF`x' = 3 if TF2004_All <= 14  & TF`x'_All > 14   & TF`x'_All ! = . &  TF2004_All! = .
	replace BchF`x' = 4 if TF`x'_All  <= 14  & TF2004_All <= 14 & TF`x'_All ! = . & TF2004_All! = .
	label values BchF`x' ch
	recode BchF`x' (1 3 = 1) (2 4 = 0), gen(BF`x')
}


bfit logit BF2006 married2004 exp2004 schooling2004 race2004 HM2004 HF2004  if lhwage2006!=.,  corder(2)
display "`r(bvlist)'"

bfit logit BF2009 married2004 exp2004 schooling2004 race2004 HM2004 HF2004 if lhwage2009!=.,  corder(2)
display "`r(bvlist)'"

bfit logit BF2015 married2004 exp2004 schooling2004 race2004 HM2004 HF2004 if lhwage2015!=.,  corder(2)
display "`r(bvlist)'"

**** Regressions for women
global cont "married2004 exp2004 age2004 schooling2004 race2004 HM2004 HF2004"

eststo ate_nnm_2006  :  teffects nnmatch (lhwage2006 $cont) (BF2006)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_nnm_2009  :  teffects nnmatch (lhwage2009 $cont) (BF2009)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_nnm_2015  :  teffects nnmatch (lhwage2015 $cont) (BF2015)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_psm_2006  :  teffects psmatch (lhwage2006)       (BF2006 exp2004 schooling2004) if flag == 1	, ate  vce(robust)  nn(1)
eststo ate_psm_2009  :  teffects psmatch (lhwage2009)       (BF2009 exp2004 schooling2004) if flag == 1	, ate  vce(robust)  nn(1)
eststo ate_psm_2015  :  teffects psmatch (lhwage2015)       (BF2015 exp2004 schooling2004) if flag == 1	, ate  vce(robust)  nn(1)
eststo atet_nnm_2006 :  teffects nnmatch (lhwage2006 $cont) (BF2006)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_nnm_2009 :  teffects nnmatch (lhwage2009 $cont) (BF2009)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_nnm_2015 :  teffects nnmatch (lhwage2015 $cont) (BF2015)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_psm_2006 :  teffects psmatch (lhwage2006)       (BF2006 exp2004 schooling2004) if flag == 1	, atet vce(robust)  nn(1)
eststo atet_psm_2009 :  teffects psmatch (lhwage2009)       (BF2009 exp2004 schooling2004) if flag == 1	, atet vce(robust)  nn(1)
eststo atet_psm_2015 :  teffects psmatch (lhwage2015)       (BF2015 exp2004 schooling2004) if flag == 1	, atet vce(robust)  nn(1)

* Plot 
coefplot (ate_nnm_2006 ,  rename(ATE:r1vs0.BF2006  = "2006")) (ate_nnm_2009 , rename(ATE:r1vs0.BF2009 = "2009")) (ate_nnm_2015 , rename(ATE:r1vs0.BF2015 = "2015")), bylabel("NN-match (ATE)") ///
	  || (ate_psm_2006 ,  rename(ATE:r1vs0.BF2006  = "2006")) (ate_psm_2009 , rename(ATE:r1vs0.BF2009 = "2009")) (ate_psm_2015 , rename(ATE:r1vs0.BF2015 = "2015")), bylabel("PS-match (ATE)") ///
	  || (atet_nnm_2006 , rename(ATET:r1vs0.BF2006  = "2006")) (atet_nnm_2009 , rename(ATET:r1vs0.BF2009 = "2009")) (atet_nnm_2015 , rename(ATET:r1vs0.BF2015 = "2015")), bylabel("NN-match (ATET)") ///
	  || (atet_psm_2006 , rename(ATET:r1vs0.BF2006  = "2006")) (atet_psm_2009 , rename(ATET:r1vs0.BF2009 = "2009")) (atet_psm_2015 , rename(ATET:r1vs0.BF2015 = "2015")), bylabel("PS-match (ATET)") ///
	  ||, xline(0) scheme(sj) norecycle byopts(legend(off)) ///
	  mlabel format(%9.3f) mlabposition(12) mlabgap(*1.21)
graph export "$res/match_women.eps", replace 
	  
			   *==========*
			   * Figure 6 *  
			   *==========*
  
foreach x of numlist  2006 2009 2015{
	gen BchM`x' = .
	replace BchM`x' = 1 if TM2004_All > 14   & TM`x'_All  > 14  &  TM`x'_All ! = . & TM2004_All! = .
	replace BchM`x' = 2 if TM2004_All > 14   & TM`x'_All  <= 14  &  TM`x'_All ! = . & TM2004_All! = .
	replace BchM`x' = 3 if TM2004_All <= 14  & TM`x'_All > 14   & TM`x'_All ! = . &  TM2004_All! = .
	replace BchM`x' = 4 if TM`x'_All  <= 14  & TM2004_All <= 14 & TM`x'_All ! = . & TM2004_All! = .
	label values BchM`x' ch
	recode BchM`x' (1 3 = 1) (2 4 = 0), gen(BM`x')
}



bfit logit BM2006 married2004 exp2004 schooling2004 race2004 HM2004 HF2004 if lhwage2006!=.,  corder(2)
display "`r(bvlist)'"

bfit logit BF2009 married2004 exp2004 schooling2004 race2004 HM2004 HF2004 if lhwage2009!=.,  corder(2)
display "`r(bvlist)'"

bfit logit BF2015 married2004 exp2004 schooling2004 race2004 HM2004 HF2004 if lhwage2015!=.,  corder(2)
display "`r(bvlist)'"

**** Regressions for men
eststo ate_nnm_2006  :  teffects nnmatch (lhwage2006 $cont) (BM2006)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_nnm_2009  :  teffects nnmatch (lhwage2009 $cont) (BM2009)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_nnm_2015  :  teffects nnmatch (lhwage2015 $cont) (BM2015)                       				, ate  vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo ate_psm_2006  :  teffects psmatch (lhwage2006)       (BM2006 exp2004              ) if flag == 1	, ate  vce(robust)  nn(1)
eststo ate_psm_2009  :  teffects psmatch (lhwage2009)       (BM2009 exp2004 schooling2004) if flag == 1	, ate  vce(robust)  nn(1)
eststo ate_psm_2015  :  teffects psmatch (lhwage2015)       (BM2015 exp2004 schooling2004) if flag == 1	, ate  vce(robust)  nn(1)
eststo atet_nnm_2006 :  teffects nnmatch (lhwage2006 $cont) (BM2006)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_nnm_2009 :  teffects nnmatch (lhwage2009 $cont) (BM2009)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_nnm_2015 :  teffects nnmatch (lhwage2015 $cont) (BM2015)                       				, atet vce(robust) biasadj(exp2004 schooling2004 age2004)
eststo atet_psm_2006 :  teffects psmatch (lhwage2006)       (BM2006 exp2004              ) if flag == 1	, atet vce(robust)  nn(1)
eststo atet_psm_2009 :  teffects psmatch (lhwage2009)       (BM2009 exp2004 schooling2004) if flag == 1	, atet vce(robust)  nn(1)
eststo atet_psm_2015 :  teffects psmatch (lhwage2015)       (BM2015 exp2004 schooling2004) if flag == 1	, atet vce(robust)  nn(1)

* Plot
coefplot (ate_nnm_2006 ,  rename(ATE:r1vs0.BM2006  = "2006")) (ate_nnm_2009 , rename(ATE:r1vs0.BM2009 = "2009")) (ate_nnm_2015 , rename(ATE:r1vs0.BM2015 = "2015")), bylabel("NN-match (ATE)") ///
	  || (ate_psm_2006 ,  rename(ATE:r1vs0.BM2006  = "2006")) (ate_psm_2009 , rename(ATE:r1vs0.BM2009 = "2009")) (ate_psm_2015 , rename(ATE:r1vs0.BM2015 = "2015")), bylabel("PS-match (ATE)") ///
	  || (atet_nnm_2006 , rename(ATET:r1vs0.BM2006  ="2006")) (atet_nnm_2009 , rename(ATET:r1vs0.BM2009 = "2009")) (atet_nnm_2015 , rename(ATET:r1vs0.BM2015 = "2015")), bylabel("NN-match (ATET)") ///
	  || (atet_psm_2006 , rename(ATET:r1vs0.BM2006  = "2006")) (atet_psm_2009 , rename(ATET:r1vs0.BM2009 = "2009")) (atet_psm_2015 , rename(ATET:r1vs0.BM2015 = "2015")), bylabel("PS-match (ATET)") ///
	  ||, xline(0) scheme(sj) norecycle byopts(legend(off)) ///
	  mlabel format(%9.3f) mlabposition(12) mlabgap(*1.21)	  
graph export "$res/match_men.eps", replace 


**** END *****
 
